@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhinit.pl,v 2.48 2003/08/02 06:15:37 ehood Exp $
+##	$Id: mhinit.pl,v 2.57 2011/01/09 07:52:25 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -64,6 +64,16 @@ $CBMessageHeadRead = undef
 $CBRawMessageBodyRead = undef
     unless defined($CBRawMessageBodyRead);
 
+## After a message has been converted
+##	&$invoke($fields, +{ folder => $filename, file => $filename });
+$CBMessageConverted = undef
+    unless defined($CBMessageConverted);
+
+## After a mail folder has been read
+##	&invoke($filename);
+$CBMailFolderRead = undef
+    unless defined($CBMailFolderRead);
+
 ## When a resource variable is being expanded:
 ##	($result, $recurse, $canclip) = &invoke($index, $varname, $arg);
 $CBRcVarExpand = undef
@@ -227,6 +237,7 @@ $LastMsgNum	= -1;	# Message number of last message
 %MsgHead  	= ();	# Message indexes to heads
 %MsgHtml  	= ();	# Flag if message is html
 %Subject  	= ();	# Message indexes to subjects
+%Time   	= ();	# Message indexes to message unix date/time
 %From   	= ();	# Message indexes to froms
 %Date   	= ();	# Message indexes to dates
 %MsgId  	= ();	# Message ids to indexes
@@ -240,6 +251,11 @@ $LastMsgNum	= -1;	# Message number of last message
 %Icons    	= ();	# Index key to icon URL for content-type
 %AddIndex 	= ();	# Flags for messages that must be written
 
+$DoFromName	= 1;
+$DoFromAddr	= 1;
+%FromName   	= ();	# Message indexes to from human name
+%FromAddr       = ();	# Message indexes to from address
+
 @MListOrder	= ();	# List of indexes in order printed on main index
 %Index2Mloc	= ();	# Map index to position in main index
 @TListOrder	= ();	# List of indexes in order printed on thread index
@@ -266,12 +282,11 @@ $DoMissingMsgs	=  0;	# Flag is missing messages should be noted in index
 %IsDefault	= ();	# Flags if certain resources are the default
 
 $bs 		= "\b";	# Used as a separator
-$Url 		= '(http://|https://|ftp://|afs://|wais://|telnet://|' .
-		   'gopher://|news:|nntp:|mid:|cid:|mailto:|prospero:)';
 
 $MLCP		= 0;	# Main index contains included files flag
 $SLOW		= 0;	# Save memory flag
 $NumOfPages	= 0;	# Number of index pages
+$NumOfPrintedPages = 0;	# Number of printed index pages
 $IdxMinPg	= -1;	# Starting page of index for updating
 $TIdxMinPg	= -1;	# Starting page of thread index for updating
 $IdxPageNum	= 0;	# Page to output if genidx
@@ -284,9 +299,15 @@ $MHeadCnvFunc	= "mhonarc::htmlize";
 $VarExp    = $ENV{'M2H_VARREGEX'};
 $VarExp    = '\$([^\$]*)\$'  if !defined($VarExp) || $VarExp !~ /\S/;
 
-##  Regexp for address/msg-id detection (looks like cussing in cartoons)
-$AddrExp  = '[^()<>@,;:\/\s"\'&|]+@[^()<>@,;:\/\s"\'&|]+';
-$HAddrExp = '[^()<>@,;:\/\s"\'&|]+(?:@|&\#[xX]0*40;|&64;)[^()<>@,;:\/\s"\'&|]+';
+##  Regexp for address/msg-id detection: In the past we had
+##  patterns that are more insync with RFC (2)822, but much
+##  of the world today uses simplier syntax.  Also, the more
+##  general versions have serious performance problems on
+##  large strings.
+#$AddrExp  = '\b[^()<>@,;:\/\s"\'&|]+@[^()<>@,;:\/\s"\'&|]+\b';
+#$HAddrExp = '\b[^()<>@,;:\/\s"\'&|]+(?:@|&\#[xX]0*40;|&64;)[^()<>@,;:\/\s"\'&|]+\b';
+$AddrExp   = '\b[A-Za-z\d\-\.+%_]+@[A-Za-z\d.\-]+\.[A-Za-z]{2,4}\b';
+$HAddrExp  = $AddrExp;
 
 ##  Text clipping function and source file: Set in mhopt.pl.
 $TextClipFunc	= undef;
@@ -309,6 +330,7 @@ $OUTDIR    = $ENV{'M2H_OUTDIR'}     || $CURDIR;
 $TTITLE    = $ENV{'M2H_TTITLE'}     || "Mail Thread Index";
 $TITLE     = $ENV{'M2H_TITLE'}      || "Mail Index";
 $MAILTOURL = $ENV{'M2H_MAILTOURL'}  || "";
+$NewsUrl   = $ENV{'M2H_NEWSURL'}  || "";
 $FROM      = $ENV{'M2H_MSGSEP'}     || '^From ';
 $LOCKFILE  = $ENV{'M2H_LOCKFILE'}   ||
 	     ($MSDOS ? "mhonarc.lck" :
@@ -347,6 +369,7 @@ $LockMethod	= set_lock_mode($LockMethod);
 
 $CONLEN      = defined($ENV{'M2H_CONLEN'})    ?  $ENV{'M2H_CONLEN'}	: 0;
 $MAIN        = defined($ENV{'M2H_MAIN'})      ?  $ENV{'M2H_MAIN'}	: 1;
+$MAXPGS      = defined($ENV{'M2H_MAXPGS'})    ?  $ENV{'M2H_MAXPGS'}	: 0;
 $MULTIIDX    = defined($ENV{'M2H_MULTIPG'})   ?  $ENV{'M2H_MULTIPG'}	: 0;
 $MODTIME     = defined($ENV{'M2H_MODTIME'})   ?  $ENV{'M2H_MODTIME'}	: 0;
 $NODOC       = defined($ENV{'M2H_DOC'})       ? !$ENV{'M2H_DOC'}	: 0;
@@ -377,6 +400,8 @@ $AddrModifyBodies  = defined($ENV{'M2H_MODIFYBODYADDRESSES'}) ?
 			     $ENV{'M2H_MODIFYBODYADDRESSES'} : undef;
 $IconURLPrefix  = defined($ENV{'M2H_ICONURLPREFIX'}) ?
 			  $ENV{'M2H_ICONURLPREFIX'} : '';
+$PrintXComments = defined($ENV{'M2H_PRINTXCOMMENTS'}) ?
+			  $ENV{'M2H_PRINTXCOMMENTS'} : 1;
 
 if ($UNIX) {
     eval {
@@ -388,6 +413,8 @@ $FilePerms      = $ENV{'M2H_FILEPERMS'} || '0666';
 $FilePermsOct   = 0666;
 $DbFilePerms    = $ENV{'M2H_DBFILEPERMS'} || '0660';
 $DbFilePermsOct = 0660;
+$FollowSymlinks = defined($ENV{'M2H_FOLLOWSYMLINKS'}) ?
+			  $ENV{'M2H_FOLLOWSYMLINKS'} : 0;
 
 $CheckNoArchive = defined($ENV{'M2H_CHECKNOARCHIVE'}) ?
 			  $ENV{'M2H_CHECKNOARCHIVE'} : 0;
@@ -445,6 +472,11 @@ $MsgExcFilter = $ENV{'M2H_MSGEXCFILTER'} || "";
 @Weekdays = $ENV{'M2H_WEEKDAYS'}    ? split(/:/, $ENV{'M2H_WEEKDAYS'})    : ();
 @weekdays = $ENV{'M2H_WEEKDAYSABR'} ? split(/:/, $ENV{'M2H_WEEKDAYSABR'}) : ();
 
+##	Location to put attachments.
+
+$AttachmentDir = $ENV{'M2H_ATTACHMENTDIR'};
+$AttachmentUrl = $ENV{'M2H_ATTACHMENTURL'} || '';
+
 ##	Many of the following are set during runtime after the
 ##	database and resources have been read.  The variables are
 ##	listed here as a quick reference.
