@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: readmail.pl,v 2.42 2011/01/09 05:13:14 ehood Exp $
+##	$Id: readmail.pl,v 2.45 2014/04/22 02:33:10 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc AT mhonarc DOT org
 ##  Description:
@@ -44,6 +44,8 @@
 
 package readmail;
 
+no warnings qw(deprecated);
+
 $DEBUG = 0;
 
 ###############################################################################
@@ -1051,7 +1053,7 @@ sub MAILparse_parameter_str {
 
     my $parm	= { };
     my @toks    = MHonArc::RFC822::uncomment($str);
-    my($tok, $name, $value, $charset, $lang, $part);
+    my($tok, $name, $value, $charset, $lang, $isPart);
 
     $parm->{'x-main'} = shift @toks  if $hasmain;
 
@@ -1069,23 +1071,26 @@ sub MAILparse_parameter_str {
         }
         ## Check if parameter is only part
         if ($name =~ s/\*(\d+)$//) {
-            $part = $1 - 1;     # we start at 0 internally
+            $isPart = 1;
         } else {
-            $part = 0;
+            $isPart = 0;
         }
         ## Set values for parameter
         $name = lc $name;
-        $parm->{$name} = {
-            'charset'	=> $charset,
-            'lang'   	=> $lang,
-        };
+        $parm->{$name} = {}  unless defined($parm->{$name});
+        $parm->{$name}{'charset'} = $charset;
+        $parm->{$name}{'lang'} = $lang;
         ## Check if value is next token
         if ($value eq "") {
             ## If value next token, than it must be quoted
             $value = shift @toks;
             $value =~ s/^"//;  $value =~ s/"$//;  $value =~ s/\\//g;
         }
-        $parm->{$name}{'vlist'}[$part] = $value;
+        if ($isPart && defined($parm->{$name}{'vlist'})) {
+          push(@{$parm->{$name}{'vlist'}}, $value);
+        } else {
+          $parm->{$name}{'vlist'} = [ $value ];
+        }
     }
 
     ## Now we loop thru each parameter and define the final values from
